@@ -60,11 +60,10 @@ class SnowConn:
         Creates an engine and connection to the specified snowflake
         db using your local snowsql credentials.
         """
+        connect_args = kwargs.get('connect_args', {})
         conn = cls()
         creds = conn._get_local_creds(local_creds_path)
-        conn._create_engine(
-            creds, db, schema, autocommit=autocommit, role=role,
-            warehouse=warehouse)
+        conn._create_engine(creds, db, schema, autocommit, role, warehouse, connect_args)
         return conn
 
     def _get_local_creds(self, local_creds_path: str = None):
@@ -115,10 +114,13 @@ class SnowConn:
                 stacklevel=2,
             )
             aws_region_name = region_name
+
+        connect_args = kwargs.get('connect_args', {})
+
         conn = SnowConn()
         creds = conn._get_secretsmanager_creds(credsman_name, aws_region_name,
                 aws_access_key_id, aws_secret_access_key)
-        conn._create_engine(creds, db, schema, autocommit, role, warehouse)
+        conn._create_engine(creds, db, schema, autocommit, role, warehouse, connect_args)
         return conn
 
     @classmethod
@@ -138,7 +140,7 @@ class SnowConn:
     def connect_credentials(cls, account: str, username: str, password: str,
                             authenticator: str = None, db: str = 'public',
                             schema: str = 'public', autocommit: bool = True,
-                            role: str = None, warehouse = None, **kwargs):
+                            role: str = None, warehouse: str = None, **kwargs):
         """
         Creates an engine and connection to the specified snowflake db using
         the provided credentials
@@ -151,7 +153,9 @@ class SnowConn:
             'PASSWORD': password,
             'AUTHENTICATOR': authenticator,
         }
-        conn._create_engine(creds, db, schema, autocommit, role, warehouse)
+
+        connect_args = kwargs.get('connect_args', {})
+        conn._create_engine(creds, db, schema, autocommit, role, warehouse, connect_args)
         return conn
 
     def _get_secretsmanager_creds(self, credsman_name: str, region_name: str,
@@ -184,7 +188,7 @@ class SnowConn:
 
     def _create_engine(self, creds: dict, db: str, schema: str,
                        autocommit: bool = True, role: str = None,
-                       warehouse=None):
+                       warehouse: str = None, connect_args: dict = {}):
 
         account = creds['ACCOUNT']
         username = creds['USERNAME']
@@ -205,7 +209,7 @@ class SnowConn:
 
         autocommit_portion = ''
         if autocommit:
-            autocommit_portion = '&autocommit=true'
+            autocommit_portion = '&autocommit=True'
 
         warehouse_portion = ''
         if warehouse:
@@ -220,7 +224,7 @@ class SnowConn:
             f'{role_portion}{autocommit_portion}{warehouse_portion}{authenticator_portion}'
         )
 
-        engine = create_engine(connection_string)
+        engine = create_engine(connection_string, connect_args=connect_args)
         self._alchemy_engine = engine
         self._connection = self._alchemy_engine.connect()
         self._raw_connection = self._connection.connection.connection
